@@ -19,6 +19,10 @@ from ..core.base import (
     ThothType,
     VectorStoreInterface,
 )
+from ..core.embedding_manager import (
+    MultilingualEmbeddingManager,
+    EmbeddingInitializationError,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -30,30 +34,43 @@ class HaystackVectorStoreAdapter(VectorStoreInterface):
         self,
         document_store: DocumentStore,
         collection_name: str,
-        embedding_model: str = "sentence-transformers/all-MiniLM-L6-v2",
+        embedding_model: str = "default",
         embedding_dim: int = 384,
+        cache_dir: str = None,
     ):
         """Initialize the Haystack adapter.
         
         Args:
             document_store: Haystack DocumentStore instance
             collection_name: Name of the collection/index
-            embedding_model: Name of the sentence transformer model
+            embedding_model: Multilingual model key or full model name
             embedding_dim: Dimension of the embeddings
+            cache_dir: Cache directory for models (auto-detect if None)
         """
         self.document_store = document_store
         self.collection_name = collection_name
         self.embedding_model = embedding_model
         self.embedding_dim = embedding_dim
+        self.cache_dir = cache_dir
 
-        # Lazy initialization of embedders
-        self._document_embedder: SentenceTransformersDocumentEmbedder | None = None
-        self._text_embedder: SentenceTransformersTextEmbedder | None = None
+        # NUOVA GESTIONE: Embedding manager centralizzato multilingua
+        try:
+            self.embedding_manager = MultilingualEmbeddingManager(
+                model_name=embedding_model,
+                cache_dir=cache_dir
+            )
+        except EmbeddingInitializationError as e:
+            logger.error(f"Failed to initialize embedding manager: {e}")
+            raise
+
+        # Manteniamo i riferimenti per compatibilità, ma deleghiamo al manager
+        self._document_embedder = None
+        self._text_embedder = None
         self._search_pipeline: Pipeline | None = None
 
         logger.info(
             f"Initialized Haystack adapter for {collection_name} "
-            f"with model {embedding_model}"
+            f"with multilingual model {self.embedding_manager.model_name}"
         )
 
     def ensure_collection_exists(self) -> None:
@@ -65,22 +82,12 @@ class HaystackVectorStoreAdapter(VectorStoreInterface):
         pass
 
     def _get_document_embedder(self) -> SentenceTransformersDocumentEmbedder:
-        """Get or create document embedder."""
-        if self._document_embedder is None:
-            self._document_embedder = SentenceTransformersDocumentEmbedder(
-                model=self.embedding_model
-            )
-            self._document_embedder.warm_up()
-        return self._document_embedder
+        """Get document embedder from multilingual manager."""
+        return self.embedding_manager.get_document_embedder()
 
     def _get_text_embedder(self) -> SentenceTransformersTextEmbedder:
-        """Get or create text embedder."""
-        if self._text_embedder is None:
-            self._text_embedder = SentenceTransformersTextEmbedder(
-                model=self.embedding_model
-            )
-            self._text_embedder.warm_up()
-        return self._text_embedder
+        """Get text embedder from multilingual manager."""
+        return self.embedding_manager.get_text_embedder()
 
     def _get_search_pipeline(self) -> Pipeline:
         """Get or create search pipeline."""
@@ -302,13 +309,11 @@ class HaystackVectorStoreAdapter(VectorStoreInterface):
             return doc.text
 
     def _add_document_with_embedding(self, doc: BaseThothDocument) -> str:
-        """Add document with embedding."""
+        """Add document with embedding using multilingual manager."""
         haystack_doc = self._convert_to_haystack_document(doc)
 
-        # Generate embedding
-        embedder = self._get_document_embedder()
-        result = embedder.run(documents=[haystack_doc])
-        embedded_docs = result["documents"]
+        # Generate embedding using multilingual manager
+        embedded_docs = self.embedding_manager.encode_documents([haystack_doc])
 
         # Store document
         self.document_store.write_documents(
@@ -411,7 +416,7 @@ class HaystackVectorStoreAdapter(VectorStoreInterface):
             logger.error(f"Error deleting document {doc_id}: {e}")
 
     def bulk_add_documents(self, documents: list[BaseThothDocument], policy: DuplicatePolicy | None = None) -> list[str]:
-        """Add multiple documents in batch."""
+        """Add multiple documents in batch using multilingual manager."""
         if not documents:
             return []
 
@@ -421,10 +426,8 @@ class HaystackVectorStoreAdapter(VectorStoreInterface):
 
         haystack_docs = [self._convert_to_haystack_document(doc) for doc in documents]
 
-        # Generate embeddings in batch
-        embedder = self._get_document_embedder()
-        result = embedder.run(documents=haystack_docs)
-        embedded_docs = result["documents"]
+        # Generate embeddings in batch using multilingual manager
+        embedded_docs = self.embedding_manager.encode_documents(haystack_docs)
 
         # Store all documents
         self.document_store.write_documents(
@@ -492,14 +495,21 @@ class HaystackVectorStoreAdapter(VectorStoreInterface):
             logger.error(f"Failed during bulk deletion of {len(doc_ids)} documents: {e}", exc_info=True)
 
     def get_collection_info(self) -> dict[str, Any]:
-        """Get collection information."""
+        """Get collection information including multilingual model details."""
         try:
             count = self.document_store.count_documents()
+            model_info = self.embedding_manager.get_model_info()
+            
             return {
                 "collection_name": self.collection_name,
                 "total_documents": count,
-                "embedding_model": self.embedding_model,
-                "embedding_dim": self.embedding_dim,
+                "embedding_model": model_info["model_name"],
+                "embedding_model_key": model_info["model_key"],
+                "embedding_dim": model_info["embedding_dimension"],
+                "is_multilingual": model_info["supports_multilingual"],
+                "is_docker": model_info["is_docker"],
+                "cache_dir": model_info["cache_dir"],
+                "initialized": model_info["initialized"],
             }
         except Exception as e:
             logger.error(f"Error getting collection info: {e}")
@@ -508,6 +518,7 @@ class HaystackVectorStoreAdapter(VectorStoreInterface):
                 "total_documents": 0,
                 "embedding_model": self.embedding_model,
                 "embedding_dim": self.embedding_dim,
+                "error": str(e),
             }
 
     def get_documents_by_type(self, thoth_type: ThothType, doc_class: type[BaseThothDocument]) -> list[BaseThothDocument]:
